==> dearun-1.0.12.tar.gz: dearun-1.0.12/dearun/deasolver.py <==
from PyQt5 import QtCore
from PyQt5.QtGui import QIcon
from PyQt5.QtWidgets import *
from CCR import MCCR
from DDF import MDDF

# 导入所画的界面
from Ui_table import Ui_Dialog

# 自定义类
class Tables(QMainWindow, Ui_Dialog):
    def __init__(self):
        super().__init__()
        self.setupUi(self)
        self.pushButton.clicked.connect(self.dataprocess)
        self.pushButton_2.clicked.connect(self.result)
        self.pushButton_3.clicked.connect(self.save)
        
    def initialize(self,df):
        # 设置表格行数和列数
        columns = df.columns
        rows = df.index
        self.tableWidget.setRowCount(len(rows))
        self.tableWidget.setColumnCount(len(columns))
        # 设置表格的列标签
        self.tableWidget.setHorizontalHeaderLabels(columns)
        # 重新设置表格区域的大小
        # self.tableWidget.setGeometry(QtCore.QRect(220, 120, 1000, 800))
        # 将数据显示在表格中
        for j in range(len(columns)):
            self.tableWidget.setColumnWidth(j, 100)
            for i in range(len(rows)):
                data = QTableWidgetItem(str(df.iloc[i][j]))
                self.tableWidget.setItem(i, j, data)
                
        # # 列宽随着内容调整
        
        # self.tableWidget.resizeColumnsToContents()
        # # 行宽随着内容调整
        # self.tableWidget.resizeRowsToContents()
        # 表格颜色交错显示
        self.tableWidget.setAlternatingRowColors(True)
    
    def final(self,df):
        columns = df.columns
        rows = df.index
        # 设置表格行数和列数
        self.tableWidget_2.setRowCount(len(rows))
        self.tableWidget_2.setColumnCount(len(columns))
        # 设置表格的列标签
        self.tableWidget_2.setHorizontalHeaderLabels(columns)
        # 重新设置表格区域的大小
        # self.tableWidget_2.setGeometry(QtCore.QRect(220, 120, 1000, 800))
        # 将数据显示在表格中
        for j in range(len(columns)):
            self.tableWidget_2.setColumnWidth(j, 100)
            for i in range(len(rows)):
                data = QTableWidgetItem(str(df.iloc[i][j]))
                self.tableWidget_2.setItem(i, j, data)
        # # 列宽随着内容调整
        # self.tableWidget_2.resizeColumnsToContents()
        # # 行宽随着内容调整
        # self.tableWidget_2.resizeRowsToContents()
        # 表格颜色交错显示
        self.tableWidget_2.setAlternatingRowColors(True)
    
    def dataprocess(self):
        openfile_name = QFileDialog.getOpenFileName(self,'选择文件','','Excel files(*.xlsx , *.xls)')
        global path_openfile_name
        path_openfile_name = openfile_name[0]
        self.df=pd.read_excel(path_openfile_name)
        self.initialize(self.df)
        
    def result(self):
        data = self.df.copy()
        self.input_cols = self.df.columns.values[1:int(self.lineEdit.text())+1]
        self.output_cols = self.df.columns.values[int(self.lineEdit.text())+1:int(self.lineEdit.text())+int(self.lineEdit_2.text())+1]
        self.printf('投入为{}'.format(self.input_cols))
        self.printf('产出为{}'.format(self.output_cols))
        self.printf('正在计算结果，请稍后')
        self.key = self.comboBox.currentText() 
        if self.key == 'CCR模型':
            model = MCCR(data=data, input_cols = self.input_cols, output_cols = self.output_cols)
            res = model.res()
        elif self.key == 'DDF模型':
            model = MDDF(data=data, input_cols = self.input_cols, output_cols = self.output_cols)
            res = model.res()
        self.printf('计算已结束')
        self.final(res)
    
    def save(self):
        self.res.to_excel(r'C:\Users\wangy\Desktop\结果_{}.xlsx'.format(self.key), index=False)

# 运行界面
def run():
    app = QApplication(sys.argv)
    tables = Tables()
    tables.show()
    sys.exit(app.exec_())

==> dearun-1.1.8.tar.gz: dearun-1.1.8/dearun/deasolver.py <==
from PyQt5 import QtCore
from PyQt5.QtGui import QIcon
from PyQt5.QtWidgets import *
from dearun.MMODEL.CCR import MCCR
from dearun.MMODEL.DDF import MDDF
# 导入所画的界面
from dearun.QT5.Ui_table import Ui_Dialog
import pandas as pd
import os

# 自定义类
class Tables(QMainWindow, Ui_Dialog):
    def __init__(self):
        super().__init__()
        self.setupUi(self)
        self.pushButton.clicked.connect(self.dataprocess)
        self.pushButton_2.clicked.connect(self.result)
        self.pushButton_3.clicked.connect(self.save)
        
    def initialize(self,df):
        # 设置表格行数和列数
        columns = df.columns
        rows = df.index
        self.tableWidget.setRowCount(len(rows))
        self.tableWidget.setColumnCount(len(columns))
        # 设置表格的列标签
        self.tableWidget.setHorizontalHeaderLabels(columns)
        # 重新设置表格区域的大小
        # self.tableWidget.setGeometry(QtCore.QRect(220, 120, 1000, 800))
        # 将数据显示在表格中
        for j in range(len(columns)):
            self.tableWidget.setColumnWidth(j, 100)
            for i in range(len(rows)):
                data = QTableWidgetItem(str(df.iloc[i][j]))
                self.tableWidget.setItem(i, j, data)
                
        # # 列宽随着内容调整
        
        # self.tableWidget.resizeColumnsToContents()
        # # 行宽随着内容调整
        # self.tableWidget.resizeRowsToContents()
        # 表格颜色交错显示
        self.tableWidget.setAlternatingRowColors(True)
    
    def final(self,df):
        columns = df.columns
        rows = df.index
        # 设置表格行数和列数
        self.tableWidget_2.setRowCount(len(rows))
        self.tableWidget_2.setColumnCount(len(columns))
        # 设置表格的列标签
        self.tableWidget_2.setHorizontalHeaderLabels(columns)
        # 重新设置表格区域的大小
        # self.tableWidget_2.setGeometry(QtCore.QRect(220, 120, 1000, 800))
        # 将数据显示在表格中
        for j in range(len(columns)):
            self.tableWidget_2.setColumnWidth(j, 100)
            for i in range(len(rows)):
                data = QTableWidgetItem(str(df.iloc[i][j]))
                self.tableWidget_2.setItem(i, j, data)
        # # 列宽随着内容调整
        # self.tableWidget_2.resizeColumnsToContents()
        # # 行宽随着内容调整
        # self.tableWidget_2.resizeRowsToContents()
        # 表格颜色交错显示
        self.tableWidget_2.setAlternatingRowColors(True)
    
    def dataprocess(self):
        openfile_name = QFileDialog.getOpenFileName(self,'选择文件','','Excel files(*.xlsx , *.xls)')
        global path_openfile_name
        path_openfile_name = openfile_name[0]
        self.df=pd.read_excel(path_openfile_name)
        self.initialize(self.df)
        
    def result(self):
        data = self.df.copy()
        self.input_cols = self.df.columns.values[1:int(self.lineEdit.text())+1]
        self.output_cols = self.df.columns.values[int(self.lineEdit.text())+1:int(self.lineEdit.text())+int(self.lineEdit_2.text())+1]
        self.printf('投入为{}'.format(self.input_cols))
        self.printf('产出为{}'.format(self.output_cols))
        self.printf('正在计算结果，请稍后')
        self.key = self.comboBox.currentText() 
        if self.key == 'CCR模型':
            model = MCCR(data=data, input_cols = self.input_cols, output_cols = self.output_cols)
            self.res = model.res()
        elif self.key == 'DDF模型':
            model = MDDF(data=data, input_cols = self.input_cols, output_cols = self.output_cols)
            self.res = model.res()
        self.printf('计算已结束')
        self.final(self.res)
    
    def save(self):
        path = os.path.split(path_openfile_name)[0]
        self.res.to_excel(path+r'\结果_{}.xlsx'.format(self.key), index=False)
        
# 运行界面
